@@ -53,9 +53,9 @@
 
 Widget::Widget(QWidget *parent):
     QWidget(parent),
-    mScreen(0),
-    mConfig(0),
-    mPrevConfig(0)
+    mScreen(nullptr),
+    mConfig(nullptr),
+    mPrevConfig(nullptr)
 {
     qRegisterMetaType<QQuickView*>();
 
@@ -190,7 +190,7 @@ void Widget::setConfig(const KScreen::ConfigPtr &config)
     if (qmlOutput) {
         mScreen->setActiveOutput(qmlOutput);
     } else {
-        if (mScreen->outputs().count() > 0) {
+        if (!mScreen->outputs().isEmpty()) {
             mScreen->setActiveOutput(mScreen->outputs()[0]);
         }
     }
